<?php
/*
 * tab authorized hosts
 */
require_once("app-classes/innovaphone.fax.database.class.php");


class AuthorizedHostsTab {

    static public function createContent(MyPage &$page, $mode) {
        $page->addSection($page->parent->currentMode, 1, true, tl::tl('Configure authorized hosts'));
        $ip = $page->addField(new InputPageText("addip", 
            tl::tl(/* http://wiki.innovaphone.com/index.php?title=Reference10:Concept_Faxserver#Authorized_Hosts */
            "Add an IP address of a host which shall be allowed to send mails without SMTP auth.") . '<br>' .
            tl::tl(/* http://wiki.innovaphone.com/index.php?title=Reference10:Concept_Faxserver#Authorized_Hosts */
            "It isn't possible to use the same fax server domain in more than one fax server configuration.")
            . '<br><br>'));
        $ipField = $page->addField(new InputPageIPField("ip", tl::tl("IP address")));
        $ipField->button = &$page->addField(new ButtonAddAuthorizedHostIp("buttonaddip", tl::tl("Ok"), $appName, $pageConfig));
        $ipField->emptyOk = true;
        $ipField->attributes["onKeyDown"] = "javascript:submitButton(event, '{$ipField->button->name}')";

        $page->addField(new InputPageHorizontalRule());

        $list = $page->addField(new MainInputPageListField("iplist") );  // will be filled in fillList
        $list->fieldOnEmptyTable = new InputPageText($list->name."emptytable", "");
        // its columns
        $fld = $list->addColumn(new InputPageTextField($list->name."ip", null), tl::tl("IP address"));
        $chkName = $list->name."chkdelete";
        $chk = $list->addColumn(new InputPageCheckboxField($chkName, null), $page->parent->getUnCheckAllInput($chkName, false));

        $page->addField(new ButtonDeleteAuthorizedHostIp("buttondeleteip", tl::tl("Delete"), $appName, $pageConfig));
    }
    
    static public function fillList(MyPage &$page, $mode) {
        $list = $page->parent->getField("iplist");
        if(!is_object($list)) return;
        $values = $list->value;
        $list->value = array();
        $return = false;
        if(($ips = AuthorizedHostsTab::readIPs()) === false) {
            $list->fieldOnEmptyTable->value = "<div style=\"color:red\">DB error</div>";
            $return = true;
        }
        else if(count($ips) == 0) {
            $list->fieldOnEmptyTable->value = "<b>".tl::tl("No IP addresses yet.")."</b>";
            $return = true;
        }
        if($return) {
            $buttonDelete = $page->parent->getField("buttondeleteip");
            $buttonDelete->autorender = false;
            return;
        }
        $rows = 0;
        $list->value = array();
        foreach($ips as $ip) {
            $list->value[$rows][$list->name."ip"] = $ip;
            $rows++;
        }
        
        if(count($values)) {   // assign certain columns now with former values, given by parameter $values
            unset($val);
            foreach($list->value as &$val) {
                foreach($values as $value) {
                    if($value[$list->name."ip"] == $val[$list->name."ip"]) {
                        $val[$list->name."chkdelete"] = isset($value[$list->name."chkdelete"]) ? $value[$list->name."chkdelete"] : null;
                        break;
                    }
                }
            }
        }
    }    

    static public function readIPs() {
        $db = new InnovaphoneFaxDatabase();
        return $db->readAuthorizedHostsIPs();
    }

    static public function addIP($ip) {
        $db = new InnovaphoneFaxDatabase();
        return $db->addAuthorizedHostsIP($ip);
    }

    static public function deleteIP($ip) {
        $db = new InnovaphoneFaxDatabase();
        return $db->deleteAuthorizedHostsIP($ip);
    }
}

class ButtonAddAuthorizedHostIp extends InputPageAction {
    var $appName;
    var $pageConfig;
    
    public function ButtonAddAuthorizedHostIp($name, $value, $appName, $pageConfig) {
        parent::__construct($name, $value);
        $this->autorender = false;
        $this->appName = $appName;
        $this->pageConfig = $pageConfig;
    }

    function action(InputPage &$page, $phase) {
        $ip = $page->getField("ip");
        if(!$ip->valid()) {
            $page->render();
            return;
        }

        $existingIPs = AuthorizedHostsTab::readIPs();
        foreach($existingIPs as $existingIP) {
            if($existingIP == $ip->value) {
                return $this->error($page, "IP address already exists.");
            }
        }

        $ret = AuthorizedHostsTab::addIP($ip->value);
        if($ret === false) {
            return $this->error($page, "DB error");
        }
        $page->warp(InputPage::relativeScriptName()."?_page={$this->pageConfig}&".$page->getArgs()."&ipadded=1");
    }
    
    function error(InputPage &$page, $error) {
        $ip = $page->getField("ip");
        $ip->msg = $error;
        $page->render();
    }
}

class ButtonDeleteAuthorizedHostIp extends InputPageButtonOnlyAction {
    var $pageConfig;
    var $appName;
    
    public function ButtonDeleteAuthorizedHostIp($name, $value, $appName, $pageConfig) {
        parent::__construct($name, $value);
        $this->appName = $appName;
        $this->pageConfig = $pageConfig;
    }

    function action(InputPage &$page, $phase) {
        $list = $page->getField("iplist");
        $ipsToDelete = array();
        foreach($list->value as $rowNumber =>$value) {
            if($value[$list->name."chkdelete"]["on"]) {
                $ipsToDelete[$rowNumber] = $value[$list->name."ip"];
            }
        }
        if(count($ipsToDelete) == 0) {
            return $this->error($page, "");
        } else {
            $error = "";
            foreach($ipsToDelete as $rowNumber => $ip) {
                $ret = AuthorizedHostsTab::deleteIP($ip);
                if($ret === false) {
                    return $this->error($page, "DB error");
                }
            }
        }
        $page->warp(InputPage::relativeScriptName()."?_page={$this->pageConfig}&".$page->getArgs()."&ipdeleted=1");
    }

    function error(InputPage &$page, $error) {
        $this->msg = $error;
        $page->render();
    }
}

?>
